{% extends "base.html" %}

{% block header %}
<h1>Key add</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
	<div class="row">
		<div class="col-md-12">
			<form action="" method="post">
				{% csrf_token %}
                {{ form.as_p }}
				<button class="btn primary" type="submit">Add</button>
			</form>
		</div>
	</div>
</div>
{% endblock %}
